using System;
using System.Runtime.InteropServices;
using System.Text;
using System.Diagnostics;
using System.IO;
using VisBuildSvr;

namespace vbp_console
{
	/// <summary>
	/// Summary description for Class1.
	/// </summary>
	class Class1
	{
		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main(string[] args)
		{
			VisBuildSvr.Application m_app;
			Builder m_bld;

			// create builder and app components and connect
			m_bld = new BuilderClass();
			m_app = new VisBuildSvr.ApplicationClass();
			m_bld.Initialize(m_app);
	
			// connect to build events
			m_bld.StepDone += new VisBuildSvr.BuilderEvents_StepDoneEventHandler(Builder_StepDone);
			m_bld.BuildDone += new VisBuildSvr.BuilderEvents_BuildDoneEventHandler(Builder_BuildDone);
			m_bld.BuildStarting += new VisBuildSvr.BuilderEvents_BuildStartingEventHandler(Builder_BuildStarting);

			// turn on file logging and use custom log file
			m_app.Options.LogFilename = LOGFILE;

			if (File.Exists(LOGFILE))
				File.Delete(LOGFILE);
        
			// load the project
			m_app.Project.Load("C:\\Program Files\\VisBuildPro\\Samples\\RegEdit.bld");
        
			// assign a temporary NUM macro value based on the user's input
			m_app.get_Macros(MacroTypeEnum.vbldMacroTemporary).Add("NUM", "123", "", "", false);
        
			Debug.Listeners.Add(new TextWriterTraceListener(Console.Out));

			// kick off the build
			m_bld.SyncBuild();	// start, wait for build to complete
			Debug.WriteLine("SyncBuild returned");
		}

		static private void Builder_StepDone(IStep step)
		{
			Debug.WriteLine("Step '" + step.Name + "' completed, status = " + step.BuildStatus);
		}

		static private void Builder_BuildStarting()
		{
			Debug.WriteLine("starting");
		}

		static private void Builder_BuildDone(BuildCompletionStatusEnum Status)
		{
			Debug.WriteLine("Build completed with status code " + Status);
			Process.Start(LOGFILE);
		}

		const string LOGFILE = "c:\\CSharpClient.txt";
	}
}
